IDORs are caused by missing access controls. If the object is accessible to authenticated users only, the endpoint
Implement a check to verify that the user making the request has permission to access the object.
